[![Build Status](https://travis-ci.org/leylabmpi/leylab_pipelines.svg?branch=master)](https://travis-ci.org/leylabmpi/leylab_pipelines)
[![PyPI version](https://badge.fury.io/py/leylab_pipelines.svg)](http://badge.fury.io/py/leylab_pipelines)


leylab_pipelines
=================

 General bioinformatic pipelines associated with the Ley Lab at the MPI in Tuebingen


#### Sections

- [Contents](#contents)
- [Examples](#examples)
- [Installation](#installation)
- [Usage](#usage)
- [Changelog](#changelog)
- [License](#license)


## Contents

[[top](#sections)]

### TECAN robot helper commands

For commands: install, then use `TECAN -h`

## Examples

[[top](#sections)]

### TECAN robot helper scripts

* See the bash scripts in:
  * `./examples/`


## Installation

[[top](#sections)]

### Testing

`python setpy.py test`

### Build

`python setup.py install`


## Changelog

[[top](#sections)]


# License

[[top](#sections)]

* Free software: MIT license
* Documentation: https://leylab-pipelines.readthedocs.io.
